@@ -18,8 +18,11 @@ package org.apache.activemq.transport.amqp.client;
 
 import java.io.IOException;
 import java.net.URI;
+import java.util.ArrayList;
+import java.util.List;
 
 import org.apache.activemq.transport.amqp.AmqpTestSupport;
+import org.junit.After;
 
 /**
  * Test support class for tests that will be using the AMQP Proton wrapper client.
@@ -29,6 +32,8 @@ public class AmqpClientTestSupport extends AmqpTestSupport {
     private String connectorScheme = "amqp";
     private boolean useSSL;
 
+    private List<AmqpConnection> connections = new ArrayList<AmqpConnection>();
+
     public AmqpClientTestSupport() {
     }
 
@@ -37,6 +42,18 @@ public class AmqpClientTestSupport extends AmqpTestSupport {
         this.useSSL = useSSL;
     }
 
+    @Override
+    @After
+    public void tearDown() throws Exception {
+        for (AmqpConnection connection : connections) {
+            try {
+                connection.close();
+            } catch (Exception ex) {}
+        }
+
+        super.tearDown();
+    }
+
     public String getConnectorScheme() {
         return connectorScheme;
     }
@@ -135,6 +152,11 @@ public class AmqpClientTestSupport extends AmqpTestSupport {
         }
     }
 
+    public AmqpConnection trackConnection(AmqpConnection connection) {
+        connections.add(connection);
+        return connection;
+    }
+
     public AmqpConnection createAmqpConnection() throws Exception {
         return createAmqpConnection(getBrokerAmqpConnectionURI());
     }
@@ -148,7 +170,7 @@ public class AmqpClientTestSupport extends AmqpTestSupport {
     }
 
     public AmqpConnection createAmqpConnection(URI brokerURI, String username, String password) throws Exception {
-        return createAmqpClient(brokerURI, username, password).connect();
+        return trackConnection(createAmqpClient(brokerURI, username, password).connect());
     }
 
     public AmqpClient createAmqpClient() throws Exception {
