@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -21,6 +21,7 @@ import static org.apache.activemq.transport.amqp.AmqpSupport.TEMP_QUEUE_CAPABILI
 import static org.apache.activemq.transport.amqp.AmqpSupport.TEMP_TOPIC_CAPABILITY;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import java.util.HashMap;
@@ -28,6 +29,7 @@ import java.util.Map;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.activemq.broker.jmx.BrokerViewMBean;
+import org.apache.activemq.transport.amqp.AmqpSupport;
 import org.apache.activemq.transport.amqp.client.AmqpClient;
 import org.apache.activemq.transport.amqp.client.AmqpClientTestSupport;
 import org.apache.activemq.transport.amqp.client.AmqpConnection;
@@ -61,7 +63,7 @@ public class AmqpTempDestinationTest extends AmqpClientTestSupport {
     protected void doTestCannotCreateSenderWithNamedTempDestination(boolean topic) throws Exception {
 
         AmqpClient client = createAmqpClient();
-        AmqpConnection connection = client.connect();
+        AmqpConnection connection = trackConnection(client.connect());
         AmqpSession session = connection.createSession();
 
         String address = null;
@@ -92,7 +94,7 @@ public class AmqpTempDestinationTest extends AmqpClientTestSupport {
     protected void doTestCannotCreateReceiverWithNamedTempDestination(boolean topic) throws Exception {
 
         AmqpClient client = createAmqpClient();
-        AmqpConnection connection = client.connect();
+        AmqpConnection connection = trackConnection(client.connect());
         AmqpSession session = connection.createSession();
 
         String address = null;
@@ -120,22 +122,33 @@ public class AmqpTempDestinationTest extends AmqpClientTestSupport {
         doTestCreateDynamicSender(false);
     }
 
+    @SuppressWarnings("unchecked")
     protected void doTestCreateDynamicSender(boolean topic) throws Exception {
         Target target = createDynamicTarget(topic);
 
         final BrokerViewMBean brokerView = getProxyToBroker();
 
         AmqpClient client = createAmqpClient();
-        AmqpConnection connection = client.connect();
+        AmqpConnection connection = trackConnection(client.connect());
         AmqpSession session = connection.createSession();
 
         AmqpSender sender = session.createSender(target);
         assertNotNull(sender);
 
+        Target remoteTarget = (Target) sender.getEndpoint().getRemoteTarget();
+        Map<Symbol, Object> dynamicNodeProperties = remoteTarget.getDynamicNodeProperties();
+        Symbol[] capabilites = remoteTarget.getCapabilities();
+
+        assertTrue(Boolean.TRUE.equals(remoteTarget.getDynamic()));
+        assertTrue(dynamicNodeProperties.containsKey(LIFETIME_POLICY));
+        assertEquals(DeleteOnClose.getInstance(), dynamicNodeProperties.get(LIFETIME_POLICY));
+
         if (topic) {
             assertEquals(1, brokerView.getTemporaryTopics().length);
+            assertTrue(AmqpSupport.contains(capabilites, TEMP_TOPIC_CAPABILITY));
         } else {
             assertEquals(1, brokerView.getTemporaryQueues().length);
+            assertTrue(AmqpSupport.contains(capabilites, TEMP_QUEUE_CAPABILITY));
         }
 
         connection.close();
@@ -157,7 +170,7 @@ public class AmqpTempDestinationTest extends AmqpClientTestSupport {
         final BrokerViewMBean brokerView = getProxyToBroker();
 
         AmqpClient client = createAmqpClient();
-        AmqpConnection connection = client.connect();
+        AmqpConnection connection = trackConnection(client.connect());
         AmqpSession session = connection.createSession();
 
         AmqpSender sender = session.createSender(target);
@@ -190,22 +203,33 @@ public class AmqpTempDestinationTest extends AmqpClientTestSupport {
         doTestCreateDynamicSender(false);
     }
 
+    @SuppressWarnings("unchecked")
     protected void doTestCreateDynamicReceiver(boolean topic) throws Exception {
         Source source = createDynamicSource(topic);
 
         final BrokerViewMBean brokerView = getProxyToBroker();
 
         AmqpClient client = createAmqpClient();
-        AmqpConnection connection = client.connect();
+        AmqpConnection connection = trackConnection(client.connect());
         AmqpSession session = connection.createSession();
 
         AmqpReceiver receiver = session.createReceiver(source);
         assertNotNull(receiver);
 
+        Source remoteSource = (Source) receiver.getEndpoint().getRemoteSource();
+        Map<Symbol, Object> dynamicNodeProperties = remoteSource.getDynamicNodeProperties();
+        Symbol[] capabilites = remoteSource.getCapabilities();
+
+        assertTrue(Boolean.TRUE.equals(remoteSource.getDynamic()));
+        assertTrue(dynamicNodeProperties.containsKey(LIFETIME_POLICY));
+        assertEquals(DeleteOnClose.getInstance(), dynamicNodeProperties.get(LIFETIME_POLICY));
+
         if (topic) {
             assertEquals(1, brokerView.getTemporaryTopics().length);
+            assertTrue(AmqpSupport.contains(capabilites, TEMP_TOPIC_CAPABILITY));
         } else {
             assertEquals(1, brokerView.getTemporaryQueues().length);
+            assertTrue(AmqpSupport.contains(capabilites, TEMP_QUEUE_CAPABILITY));
         }
 
         connection.close();
@@ -227,7 +251,7 @@ public class AmqpTempDestinationTest extends AmqpClientTestSupport {
         final BrokerViewMBean brokerView = getProxyToBroker();
 
         AmqpClient client = createAmqpClient();
-        AmqpConnection connection = client.connect();
+        AmqpConnection connection = trackConnection(client.connect());
         AmqpSession session = connection.createSession();
 
         AmqpReceiver receiver = session.createReceiver(source);
@@ -266,7 +290,7 @@ public class AmqpTempDestinationTest extends AmqpClientTestSupport {
         final BrokerViewMBean brokerView = getProxyToBroker();
 
         AmqpClient client = createAmqpClient();
-        AmqpConnection connection = client.connect();
+        AmqpConnection connection = trackConnection(client.connect());
         AmqpSession session = connection.createSession();
 
         AmqpSender sender = session.createSender(target);
@@ -319,7 +343,7 @@ public class AmqpTempDestinationTest extends AmqpClientTestSupport {
         final BrokerViewMBean brokerView = getProxyToBroker();
 
         AmqpClient client = createAmqpClient();
-        AmqpConnection connection = client.connect();
+        AmqpConnection connection = trackConnection(client.connect());
         AmqpSession session = connection.createSession();
 
         AmqpReceiver receiver = session.createReceiver(source);
