@@ -17,6 +17,7 @@
 package org.apache.activemq.advisory;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Iterator;
@@ -42,6 +43,7 @@ import org.apache.activemq.broker.region.Subscription;
 import org.apache.activemq.broker.region.TopicRegion;
 import org.apache.activemq.broker.region.TopicSubscription;
 import org.apache.activemq.broker.region.virtual.VirtualDestination;
+import org.apache.activemq.broker.region.virtual.VirtualTopic;
 import org.apache.activemq.command.ActiveMQDestination;
 import org.apache.activemq.command.ActiveMQMessage;
 import org.apache.activemq.command.ActiveMQTopic;
@@ -58,6 +60,7 @@ import org.apache.activemq.command.ProducerId;
 import org.apache.activemq.command.ProducerInfo;
 import org.apache.activemq.command.RemoveSubscriptionInfo;
 import org.apache.activemq.command.SessionId;
+import org.apache.activemq.filter.DestinationPath;
 import org.apache.activemq.security.SecurityContext;
 import org.apache.activemq.state.ProducerState;
 import org.apache.activemq.usage.Usage;
@@ -206,7 +209,7 @@ public class AdvisoryBroker extends BrokerFilter {
                 for (Iterator<ConsumerInfo> iter = virtualDestinationConsumers.keySet().iterator(); iter.hasNext(); ) {
                     ConsumerInfo key = iter.next();
                     ActiveMQTopic topic = AdvisorySupport.getVirtualDestinationConsumerAdvisoryTopic(key.getDestination());
-                    fireConsumerAdvisory(context, key.getDestination(), topic, key);
+                    fireConsumerAdvisory(context, key.getDestination(), topic, key, info.getConsumerId());
               }
             }
 
@@ -226,8 +229,10 @@ public class AdvisoryBroker extends BrokerFilter {
     public void addProducer(ConnectionContext context, ProducerInfo info) throws Exception {
         super.addProducer(context, info);
 
-        // Don't advise advisory topics.
-        if (info.getDestination() != null && !AdvisorySupport.isAdvisoryTopic(info.getDestination())) {
+        //Verify destination is either non-null or that we want to advise anonymous producers on null destination
+        //Don't advise advisory topics.
+        if ((info.getDestination() != null || getBrokerService().isAnonymousProducerAdvisorySupport())
+                && !AdvisorySupport.isAdvisoryTopic(info.getDestination())) {
             ActiveMQTopic topic = AdvisorySupport.getProducerAdvisoryTopic(info.getDestination());
             fireProducerAdvisory(context, info.getDestination(), topic, info);
             producers.put(info.getProducerId(), info);
@@ -289,11 +294,10 @@ public class AdvisoryBroker extends BrokerFilter {
                         //in case of multiple matches
                         VirtualConsumerPair key = new VirtualConsumerPair(virtualDestination, destination);
                         ConsumerInfo i = brokerConsumerDests.get(key);
-                        if (consumerInfo.equals(i)) {
-                            if (brokerConsumerDests.remove(key) != null) {
-                                fireVirtualDestinationRemoveAdvisory(context, consumerInfo);
-                                break;
-                            }
+                        if (consumerInfo.equals(i) && brokerConsumerDests.remove(key) != null) {
+                            LOG.debug("Virtual consumer pair removed: {} for consumer: {} ", key, i);
+                            fireVirtualDestinationRemoveAdvisory(context, consumerInfo);
+                            break;
                         }
                     }
                 }
@@ -410,12 +414,13 @@ public class AdvisoryBroker extends BrokerFilter {
     public void removeProducer(ConnectionContext context, ProducerInfo info) throws Exception {
         super.removeProducer(context, info);
 
-        // Don't advise advisory topics.
+        //Verify destination is either non-null or that we want to advise anonymous producers on null destination
+        //Don't advise advisory topics.
         ActiveMQDestination dest = info.getDestination();
-        if (info.getDestination() != null && !AdvisorySupport.isAdvisoryTopic(dest)) {
+        if ((dest != null || getBrokerService().isAnonymousProducerAdvisorySupport()) && !AdvisorySupport.isAdvisoryTopic(dest)) {
             ActiveMQTopic topic = AdvisorySupport.getProducerAdvisoryTopic(dest);
             producers.remove(info.getProducerId());
-            if (!dest.isTemporary() || destinations.containsKey(dest)) {
+            if (dest == null || !dest.isTemporary() || destinations.containsKey(dest)) {
                 fireProducerAdvisory(context, dest, topic, info.createRemoveCommand());
             }
         }
@@ -549,6 +554,7 @@ public class AdvisoryBroker extends BrokerFilter {
         super.virtualDestinationAdded(context, virtualDestination);
 
         if (virtualDestinations.add(virtualDestination)) {
+            LOG.debug("Virtual destination added: {}", virtualDestination);
             try {
                 // Don't advise advisory topics.
                 if (!AdvisorySupport.isAdvisoryTopic(virtualDestination.getVirtualDestination())) {
@@ -592,40 +598,86 @@ public class AdvisoryBroker extends BrokerFilter {
         //if no consumer info, we need to create one - this is the case when an advisory is fired
         //because of the existence of a destination matching a virtual destination
         if (info == null) {
-            ConnectionId connectionId = new ConnectionId(connectionIdGenerator.generateId());
-            SessionId sessionId = new SessionId(connectionId, sessionIdGenerator.getNextSequenceId());
-            ConsumerId consumerId = new ConsumerId(sessionId, consumerIdGenerator.getNextSequenceId());
-
-            info = new ConsumerInfo(consumerId);
 
             //store the virtual destination and the activeMQDestination as a pair so that we can keep track
             //of all matching forwarded destinations that caused demand
-            if(brokerConsumerDests.putIfAbsent(new VirtualConsumerPair(virtualDestination, activeMQDest), info) == null) {
-                info.setDestination(virtualDestination.getVirtualDestination());
-                ActiveMQTopic topic = AdvisorySupport.getVirtualDestinationConsumerAdvisoryTopic(info.getDestination());
+            VirtualConsumerPair pair = new VirtualConsumerPair(virtualDestination, activeMQDest);
+            if (brokerConsumerDests.get(pair) == null) {
+                ConnectionId connectionId = new ConnectionId(connectionIdGenerator.generateId());
+                SessionId sessionId = new SessionId(connectionId, sessionIdGenerator.getNextSequenceId());
+                ConsumerId consumerId = new ConsumerId(sessionId, consumerIdGenerator.getNextSequenceId());
+                info = new ConsumerInfo(consumerId);
 
-                if (virtualDestinationConsumers.putIfAbsent(info, virtualDestination) == null) {
-                    fireConsumerAdvisory(context, info.getDestination(), topic, info);
+                if(brokerConsumerDests.putIfAbsent(pair, info) == null) {
+                    LOG.debug("Virtual consumer pair added: {} for consumer: {} ", pair, info);
+                    setConsumerInfoVirtualDest(info, virtualDestination, activeMQDest);
+                    ActiveMQTopic topic = AdvisorySupport.getVirtualDestinationConsumerAdvisoryTopic(info.getDestination());
+
+                    if (virtualDestinationConsumers.putIfAbsent(info, virtualDestination) == null) {
+                        LOG.debug("Virtual consumer added: {}, for virtual destination: {}", info, virtualDestination);
+                        fireConsumerAdvisory(context, info.getDestination(), topic, info);
+                    }
                 }
             }
         //this is the case of a real consumer coming online
         } else {
             info = info.copy();
-            info.setDestination(virtualDestination.getVirtualDestination());
+            setConsumerInfoVirtualDest(info, virtualDestination, activeMQDest);
             ActiveMQTopic topic = AdvisorySupport.getVirtualDestinationConsumerAdvisoryTopic(info.getDestination());
 
             if (virtualDestinationConsumers.putIfAbsent(info, virtualDestination) == null) {
+                LOG.debug("Virtual consumer added: {}, for virtual destination: {}", info, virtualDestination);
                 fireConsumerAdvisory(context, info.getDestination(), topic, info);
             }
         }
     }
 
+    /**
+     * Sets the virtual destination on the ConsumerInfo
+     * If this is a VirtualTopic then the destination used will be the actual topic subscribed
+     * to in order to track demand properly
+     *
+     * @param info
+     * @param virtualDestination
+     * @param activeMQDest
+     */
+    private void setConsumerInfoVirtualDest(ConsumerInfo info, VirtualDestination virtualDestination, ActiveMQDestination activeMQDest) {
+        info.setDestination(virtualDestination.getVirtualDestination());
+        if (virtualDestination instanceof VirtualTopic) {
+            VirtualTopic vt = (VirtualTopic) virtualDestination;
+            String prefix = vt.getPrefix() != null ? vt.getPrefix() : "";
+            String postfix = vt.getPostfix() != null ? vt.getPostfix() : "";
+            if (prefix.endsWith(".")) {
+                prefix = prefix.substring(0, prefix.length() - 1);
+            }
+            if (postfix.startsWith(".")) {
+                postfix = postfix.substring(1, postfix.length());
+            }
+            ActiveMQDestination prefixDestination = prefix.length() > 0 ? new ActiveMQTopic(prefix) : null;
+            ActiveMQDestination postfixDestination = postfix.length() > 0 ? new ActiveMQTopic(postfix) : null;
+
+            String[] prefixPaths = prefixDestination != null ? prefixDestination.getDestinationPaths() : new String[] {};
+            String[] activeMQDestPaths = activeMQDest.getDestinationPaths();
+            String[] postfixPaths = postfixDestination != null ? postfixDestination.getDestinationPaths() : new String[] {};
+
+            //sanity check
+            if (activeMQDestPaths.length > prefixPaths.length + postfixPaths.length) {
+                String[] topicPath = Arrays.copyOfRange(activeMQDestPaths, 0 + prefixPaths.length,
+                        activeMQDestPaths.length - postfixPaths.length);
+
+                ActiveMQTopic newTopic = new ActiveMQTopic(DestinationPath.toString(topicPath));
+                info.setDestination(newTopic);
+            }
+        }
+    }
+
     @Override
     public void virtualDestinationRemoved(ConnectionContext context,
             VirtualDestination virtualDestination) {
         super.virtualDestinationRemoved(context, virtualDestination);
 
         if (virtualDestinations.remove(virtualDestination)) {
+            LOG.debug("Virtual destination removed: {}", virtualDestination);
             try {
                 consumersLock.readLock().lock();
                 try {
@@ -636,16 +688,17 @@ public class AdvisoryBroker extends BrokerFilter {
                                 //find all consumers for this virtual destination
                                 if (virtualDestinationConsumers.get(info).equals(virtualDestination)) {
                                     fireVirtualDestinationRemoveAdvisory(context, info);
-                                }
 
-                                //check consumers created for the existence of a destination to see if they
-                                //match the consumerinfo and clean up
-                                for (VirtualConsumerPair activeMQDest : brokerConsumerDests.keySet()) {
-                                    ConsumerInfo i = brokerConsumerDests.get(activeMQDest);
-                                    if (info.equals(i)) {
-                                        brokerConsumerDests.remove(activeMQDest);
+                                    //check consumers created for the existence of a destination to see if they
+                                    //match the consumerinfo and clean up
+                                    for (VirtualConsumerPair activeMQDest : brokerConsumerDests.keySet()) {
+                                        ConsumerInfo i = brokerConsumerDests.get(activeMQDest);
+                                        if (info.equals(i) && brokerConsumerDests.remove(activeMQDest) != null) {
+                                            LOG.debug("Virtual consumer pair removed: {} for consumer: {} ", activeMQDest, i);
+                                        }
                                     }
                                 }
+
                             }
                         }
                     }
@@ -663,6 +716,7 @@ public class AdvisoryBroker extends BrokerFilter {
 
         VirtualDestination virtualDestination = virtualDestinationConsumers.remove(info);
         if (virtualDestination != null) {
+            LOG.debug("Virtual consumer removed: {}, for virtual destination: {}", info, virtualDestination);
             ActiveMQTopic topic = AdvisorySupport.getVirtualDestinationConsumerAdvisoryTopic(virtualDestination.getVirtualDestination());
 
             ActiveMQDestination dest = info.getDestination();
@@ -674,7 +728,7 @@ public class AdvisoryBroker extends BrokerFilter {
     }
 
     @Override
-    public void isFull(ConnectionContext context, Destination destination, Usage usage) {
+    public void isFull(ConnectionContext context, Destination destination, Usage<?> usage) {
         super.isFull(context, destination, usage);
         if (AdvisorySupport.isAdvisoryTopic(destination.getActiveMQDestination()) == false) {
             try {
@@ -682,6 +736,7 @@ public class AdvisoryBroker extends BrokerFilter {
                 ActiveMQTopic topic = AdvisorySupport.getFullAdvisoryTopic(destination.getActiveMQDestination());
                 ActiveMQMessage advisoryMessage = new ActiveMQMessage();
                 advisoryMessage.setStringProperty(AdvisorySupport.MSG_PROPERTY_USAGE_NAME, usage.getName());
+                advisoryMessage.setLongProperty(AdvisorySupport.MSG_PROPERTY_USAGE_COUNT, usage.getUsage());
                 fireAdvisory(context, topic, null, null, advisoryMessage);
 
             } catch (Exception e) {
@@ -822,43 +877,41 @@ public class AdvisoryBroker extends BrokerFilter {
     }
 
     public void fireAdvisory(ConnectionContext context, ActiveMQTopic topic, Command command, ConsumerId targetConsumerId, ActiveMQMessage advisoryMessage) throws Exception {
-        if (getBrokerService().isStarted()) {
-            //set properties
-            advisoryMessage.setStringProperty(AdvisorySupport.MSG_PROPERTY_ORIGIN_BROKER_NAME, getBrokerName());
-            String id = getBrokerId() != null ? getBrokerId().getValue() : "NOT_SET";
-            advisoryMessage.setStringProperty(AdvisorySupport.MSG_PROPERTY_ORIGIN_BROKER_ID, id);
+        //set properties
+        advisoryMessage.setStringProperty(AdvisorySupport.MSG_PROPERTY_ORIGIN_BROKER_NAME, getBrokerName());
+        String id = getBrokerId() != null ? getBrokerId().getValue() : "NOT_SET";
+        advisoryMessage.setStringProperty(AdvisorySupport.MSG_PROPERTY_ORIGIN_BROKER_ID, id);
 
-            String url = getBrokerService().getVmConnectorURI().toString();
-            //try and find the URL on the transport connector and use if it exists else
-            //try and find a default URL
-            if (context.getConnector() instanceof TransportConnector
-                    && ((TransportConnector) context.getConnector()).getPublishableConnectString() != null) {
-                url = ((TransportConnector) context.getConnector()).getPublishableConnectString();
-            } else if (getBrokerService().getDefaultSocketURIString() != null) {
-                url = getBrokerService().getDefaultSocketURIString();
-            }
-            advisoryMessage.setStringProperty(AdvisorySupport.MSG_PROPERTY_ORIGIN_BROKER_URL, url);
+        String url = getBrokerService().getVmConnectorURI().toString();
+        //try and find the URL on the transport connector and use if it exists else
+        //try and find a default URL
+        if (context.getConnector() instanceof TransportConnector
+                && ((TransportConnector) context.getConnector()).getPublishableConnectString() != null) {
+            url = ((TransportConnector) context.getConnector()).getPublishableConnectString();
+        } else if (getBrokerService().getDefaultSocketURIString() != null) {
+            url = getBrokerService().getDefaultSocketURIString();
+        }
+        advisoryMessage.setStringProperty(AdvisorySupport.MSG_PROPERTY_ORIGIN_BROKER_URL, url);
 
-            //set the data structure
-            advisoryMessage.setDataStructure(command);
-            advisoryMessage.setPersistent(false);
-            advisoryMessage.setType(AdvisorySupport.ADIVSORY_MESSAGE_TYPE);
-            advisoryMessage.setMessageId(new MessageId(advisoryProducerId, messageIdGenerator.getNextSequenceId()));
-            advisoryMessage.setTargetConsumerId(targetConsumerId);
-            advisoryMessage.setDestination(topic);
-            advisoryMessage.setResponseRequired(false);
-            advisoryMessage.setProducerId(advisoryProducerId);
-            boolean originalFlowControl = context.isProducerFlowControl();
-            final ProducerBrokerExchange producerExchange = new ProducerBrokerExchange();
-            producerExchange.setConnectionContext(context);
-            producerExchange.setMutable(true);
-            producerExchange.setProducerState(new ProducerState(new ProducerInfo()));
-            try {
-                context.setProducerFlowControl(false);
-                next.send(producerExchange, advisoryMessage);
-            } finally {
-                context.setProducerFlowControl(originalFlowControl);
-            }
+        //set the data structure
+        advisoryMessage.setDataStructure(command);
+        advisoryMessage.setPersistent(false);
+        advisoryMessage.setType(AdvisorySupport.ADIVSORY_MESSAGE_TYPE);
+        advisoryMessage.setMessageId(new MessageId(advisoryProducerId, messageIdGenerator.getNextSequenceId()));
+        advisoryMessage.setTargetConsumerId(targetConsumerId);
+        advisoryMessage.setDestination(topic);
+        advisoryMessage.setResponseRequired(false);
+        advisoryMessage.setProducerId(advisoryProducerId);
+        boolean originalFlowControl = context.isProducerFlowControl();
+        final ProducerBrokerExchange producerExchange = new ProducerBrokerExchange();
+        producerExchange.setConnectionContext(context);
+        producerExchange.setMutable(true);
+        producerExchange.setProducerState(new ProducerState(new ProducerInfo()));
+        try {
+            context.setProducerFlowControl(false);
+            next.send(producerExchange, advisoryMessage);
+        } finally {
+            context.setProducerFlowControl(originalFlowControl);
         }
     }
 
@@ -883,6 +936,10 @@ public class AdvisoryBroker extends BrokerFilter {
         return destinations;
     }
 
+    public ConcurrentMap<ConsumerInfo, VirtualDestination> getVirtualDestinationConsumers() {
+        return virtualDestinationConsumers;
+    }
+
     private class VirtualConsumerPair {
         private final VirtualDestination virtualDestination;
 
@@ -897,6 +954,7 @@ public class AdvisoryBroker extends BrokerFilter {
             this.virtualDestination = virtualDestination;
             this.activeMQDestination = activeMQDestination;
         }
+
         @Override
         public int hashCode() {
             final int prime = 31;
@@ -912,6 +970,7 @@ public class AdvisoryBroker extends BrokerFilter {
                             .hashCode());
             return result;
         }
+
         @Override
         public boolean equals(Object obj) {
             if (this == obj)
@@ -935,6 +994,13 @@ public class AdvisoryBroker extends BrokerFilter {
                 return false;
             return true;
         }
+
+        @Override
+        public String toString() {
+            return "VirtualConsumerPair [virtualDestination=" + virtualDestination + ", activeMQDestination="
+                    + activeMQDestination + "]";
+        }
+
         private AdvisoryBroker getOuterType() {
             return AdvisoryBroker.this;
         }
