@@ -245,8 +245,8 @@ public abstract class AbstractRegion implements Region {
                     rc.add(sub);
                 } catch (SecurityException e) {
                     if (sub.isWildcard()) {
-                        LOG.debug("Subscription denied for " + sub + " to destination " +
-                            dest.getActiveMQDestination() +  ": " + e.getMessage());
+                        LOG.debug("Subscription denied for {} to destination {}: {}",
+                                sub, dest.getActiveMQDestination(), e.getMessage());
                     } else {
                         throw e;
                     }
@@ -267,7 +267,7 @@ public abstract class AbstractRegion implements Region {
             for (Iterator<Subscription> iter = subscriptions.values().iterator(); iter.hasNext();) {
                 Subscription sub = iter.next();
                 if (sub.matches(destination) ) {
-                    throw new JMSException("Destination still has an active subscription: " + destination);
+                    throw new JMSException("Destination: " + destination + " still has an active subscription: " + sub);
                 }
             }
         }
@@ -338,7 +338,8 @@ public abstract class AbstractRegion implements Region {
     @Override
     @SuppressWarnings("unchecked")
     public Subscription addConsumer(ConnectionContext context, ConsumerInfo info) throws Exception {
-        LOG.debug("{} adding consumer: {} for destination: {}", new Object[]{ broker.getBrokerName(), info.getConsumerId(), info.getDestination() });
+        LOG.debug("{} adding consumer: {} for destination: {}",
+                broker.getBrokerName(), info.getConsumerId(), info.getDestination());
         ActiveMQDestination destination = info.getDestination();
         if (destination != null && !destination.isPattern() && !destination.isComposite()) {
             // lets auto-create the destination
@@ -406,15 +407,16 @@ public abstract class AbstractRegion implements Region {
                     removeList.add(dest);
                 } catch (SecurityException e){
                     if (sub.isWildcard()) {
-                        LOG.debug("Subscription denied for " + sub + " to destination " +
-                            dest.getActiveMQDestination() + ": " + e.getMessage());
+                        LOG.debug("Subscription denied for {} to destination {}: {}",
+                                sub, dest.getActiveMQDestination(), e.getMessage());
                     } else {
                         // remove partial subscriptions
                         for (Destination remove : removeList) {
                             try {
                                 remove.removeSubscription(context, sub, info.getLastDeliveredSequenceId());
                             } catch (Exception ex) {
-                                LOG.error("Error unsubscribing " + sub + " from " + remove + ": " + ex.getMessage(), ex);
+                                LOG.error("Error unsubscribing {} from {}: {}",
+                                        sub, remove, ex.getMessage(), ex);
                             }
                         }
                         subscriptions.remove(info.getConsumerId());
@@ -460,7 +462,8 @@ public abstract class AbstractRegion implements Region {
     @Override
     @SuppressWarnings("unchecked")
     public void removeConsumer(ConnectionContext context, ConsumerInfo info) throws Exception {
-        LOG.debug("{} removing consumer: {} for destination: {}", new Object[]{ broker.getBrokerName(), info.getConsumerId(), info.getDestination() });
+        LOG.debug("{} removing consumer: {} for destination: {}",
+                broker.getBrokerName(), info.getConsumerId(), info.getDestination());
 
         Subscription sub = subscriptions.remove(info.getConsumerId());
         // The sub could be removed elsewhere - see ConnectionSplitBroker
@@ -685,7 +688,8 @@ public abstract class AbstractRegion implements Region {
                     entry.configurePrefetch(sub);
                 }
             }
-            LOG.debug("setting prefetch: {}, on subscription: {}; resulting value: {}", new Object[]{ control.getPrefetch(), control.getConsumerId(), sub.getConsumerInfo().getPrefetchSize()});
+            LOG.debug("setting prefetch: {}, on subscription: {}; resulting value: {}",
+                    control.getPrefetch(), control.getConsumerId(), sub.getConsumerInfo().getPrefetchSize());
             try {
                 lookup(consumerExchange.getConnectionContext(), control.getDestination(),false).wakeup();
             } catch (Exception e) {
