@@ -174,7 +174,6 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                             pending.remove();
                             createMessageDispatch(node, node.getMessage());
                             dispatched.add(node);
-                            getSubscriptionStatistics().getInflightMessageSize().addSize(node.getSize());
                             onDispatch(node, node.getMessage());
                         }
                         return;
@@ -224,7 +223,6 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                         // Don't remove the nodes until we are committed.
                         if (!context.isInTransaction()) {
                             getSubscriptionStatistics().getDequeues().increment();
-                            ((Destination)node.getRegionDestination()).getDestinationStatistics().getInflight().decrement();
                             removeList.add(node);
                             contractPrefetchExtension(1);
                         } else {
@@ -240,7 +238,7 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                 }
                 for (final MessageReference node : removeList) {
                     dispatched.remove(node);
-                    getSubscriptionStatistics().getInflightMessageSize().addSize(-node.getSize());
+                    decrementPrefetchCounter(node);
                 }
                 // this only happens after a reconnect - get an ack which is not
                 // valid
@@ -256,9 +254,8 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                         // Don't remove the nodes until we are committed - immediateAck option
                         if (!context.isInTransaction()) {
                             getSubscriptionStatistics().getDequeues().increment();
-                            ((Destination)node.getRegionDestination()).getDestinationStatistics().getInflight().decrement();
                             dispatched.remove(node);
-                            getSubscriptionStatistics().getInflightMessageSize().addSize(-node.getSize());
+                            decrementPrefetchCounter(node);
                             contractPrefetchExtension(1);
                         } else {
                             registerRemoveSync(context, node);
@@ -306,7 +303,7 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                             regionDestination.messageExpired(context, this, node);
                         }
                         iter.remove();
-                        nodeDest.getDestinationStatistics().getInflight().decrement();
+                        decrementPrefetchCounter(node);
 
                         if (ack.getLastMessageId().equals(messageId)) {
                             contractPrefetchExtension(1);
@@ -364,8 +361,6 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                     if (inAckRange) {
                         sendToDLQ(context, node, ack.getPoisonCause());
                         Destination nodeDest = (Destination) node.getRegionDestination();
-                        nodeDest.getDestinationStatistics()
-                        .getInflight().decrement();
                         removeList.add(node);
                         getSubscriptionStatistics().getDequeues().increment();
                         index++;
@@ -380,7 +375,7 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                 }
                 for (final MessageReference node : removeList) {
                     dispatched.remove(node);
-                    getSubscriptionStatistics().getInflightMessageSize().addSize(-node.getSize());
+                    decrementPrefetchCounter(node);
                 }
                 if (!callDispatchMatched) {
                     throw new JMSException(
@@ -413,9 +408,11 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                         Destination nodeDest = (Destination) node.getRegionDestination();
                         synchronized (dispatchLock) {
                             getSubscriptionStatistics().getDequeues().increment();
-                            dispatched.remove(node);
-                            getSubscriptionStatistics().getInflightMessageSize().addSize(-node.getSize());
-                            nodeDest.getDestinationStatistics().getInflight().decrement();
+                            if (dispatched.remove(node)) {
+                                // if consumer is removed, dispatched will be empty and inflight will
+                                // already have been adjusted
+                                decrementPrefetchCounter(node);
+                            }
                         }
                         contractPrefetchExtension(1);
                         nodeDest.wakeup();
@@ -613,10 +610,12 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
         for (MessageReference r : dispatched) {
             if (r.getRegionDestination() == destination) {
                 references.add(r);
+                //Decrement the size as we are removing and redispatching all references
                 getSubscriptionStatistics().getInflightMessageSize().addSize(-r.getSize());
             }
         }
         redispatch.addAll(0, references);
+        //Clean up in flight message stats on the destination after dispatched is cleared
         destination.getDestinationStatistics().getInflight().subtract(references.size());
         dispatched.removeAll(references);
     }
@@ -638,6 +637,10 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                         if (node == null) {
                             break;
                         }
+                        if (trackedInPendingTransaction(node)) {
+                            node.decrementReferenceCount();
+                            continue;
+                        }
 
                         // Synchronize between dispatched list and remove of message from pending list
                         // related to remove subscription action
@@ -666,7 +669,7 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                         // decrement after dispatch has taken ownership to avoid usage jitter
                         node.decrementReferenceCount();
                     }
-                } else if (!isSlowConsumer()) {
+                } else if (!pending.isEmpty() && !isSlowConsumer()) {
                     setSlowConsumer(true);
                     slowConsumerTargets = destinations;
                 }
@@ -682,6 +685,10 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
         }
     }
 
+    protected boolean trackedInPendingTransaction(MessageReference node) {
+        return false;
+    }
+
     protected void setPendingBatchSize(PendingMessageCursor pending, int numberToDispatch) {
         pending.setMaxBatchSize(numberToDispatch);
     }
@@ -697,9 +704,8 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
 
         MessageDispatch md = createMessageDispatch(node, message);
         if (node != QueueMessageReference.NULL_MESSAGE) {
-            getSubscriptionStatistics().getDispatched().increment();
             dispatched.add(node);
-            getSubscriptionStatistics().getInflightMessageSize().addSize(node.getSize());
+            getSubscriptionStatistics().getDispatched().increment();
         }
         if (getPrefetchSize() == 0) {
             while (true) {
@@ -726,8 +732,13 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
                     if (nodeDest != null) {
                         if (node != QueueMessageReference.NULL_MESSAGE) {
                             nodeDest.getDestinationStatistics().getDispatched().increment();
-                            nodeDest.getDestinationStatistics().getInflight().increment();
-                            LOG.trace("{} failed to dispatch: {} - {}, dispatched: {}, inflight: {}", new Object[]{ info.getConsumerId(), message.getMessageId(), message.getDestination(), getSubscriptionStatistics().getDispatched().getCount(), dispatched.size() });
+                            //We still increment here as the dispatched list is still tracking references at this point
+                            //Metrics will get cleaned up in addReferencesAndUpdateRedispatch() when the dispatched
+                            //list is also cleaned up as the failure causes the subscription to close
+                            incrementPrefetchCounter(node);
+                            LOG.trace("{} failed to dispatch: {} - {}, dispatched: {}, inflight: {}",
+                                    info.getConsumerId(), message.getMessageId(), message.getDestination(),
+                                    getSubscriptionStatistics().getDispatched().getCount(), dispatched.size());
                         }
                     }
                     if (node instanceof QueueMessageReference) {
@@ -748,8 +759,10 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
         if (nodeDest != null) {
             if (node != QueueMessageReference.NULL_MESSAGE) {
                 nodeDest.getDestinationStatistics().getDispatched().increment();
-                nodeDest.getDestinationStatistics().getInflight().increment();
-                LOG.trace("{} dispatched: {} - {}, dispatched: {}, inflight: {}", new Object[]{ info.getConsumerId(), message.getMessageId(), message.getDestination(), getSubscriptionStatistics().getDispatched().getCount(), dispatched.size() });
+                incrementPrefetchCounter(node);
+                LOG.trace("{} dispatched: {} - {}, dispatched: {}, inflight: {}",
+                        info.getConsumerId(), message.getMessageId(), message.getDestination(),
+                        getSubscriptionStatistics().getDispatched().getCount(), dispatched.size());
             }
         }
 
@@ -850,4 +863,14 @@ public abstract class PrefetchSubscription extends AbstractSubscription {
             LOG.trace("Caught exception during dispatch after prefetch change.", e);
         }
     }
+
+    private void incrementPrefetchCounter(final MessageReference node) {
+        ((Destination)node.getRegionDestination()).getDestinationStatistics().getInflight().increment();
+        getSubscriptionStatistics().getInflightMessageSize().addSize(node.getSize());
+    }
+
+    private void decrementPrefetchCounter(final MessageReference node) {
+        ((Destination)node.getRegionDestination()).getDestinationStatistics().getInflight().decrement();
+        getSubscriptionStatistics().getInflightMessageSize().addSize(-node.getSize());
+    }
 }
