@@ -56,7 +56,6 @@ import org.apache.activemq.command.MessageAck;
 import org.apache.activemq.command.MessageId;
 import org.apache.activemq.command.ProducerId;
 import org.apache.activemq.command.SubscriptionInfo;
-import org.apache.activemq.command.TransactionId;
 import org.apache.activemq.openwire.OpenWireFormat;
 import org.apache.activemq.protobuf.Buffer;
 import org.apache.activemq.store.AbstractMessageStore;
@@ -106,8 +105,8 @@ public class KahaDBStore extends MessageDatabase implements PersistenceAdapter,
 
     protected ExecutorService queueExecutor;
     protected ExecutorService topicExecutor;
-    protected final List<Map<AsyncJobKey, StoreTask>> asyncQueueMaps = new LinkedList<Map<AsyncJobKey, StoreTask>>();
-    protected final List<Map<AsyncJobKey, StoreTask>> asyncTopicMaps = new LinkedList<Map<AsyncJobKey, StoreTask>>();
+    protected final List<Map<AsyncJobKey, StoreTask>> asyncQueueMaps = new LinkedList<>();
+    protected final List<Map<AsyncJobKey, StoreTask>> asyncTopicMaps = new LinkedList<>();
     final WireFormat wireFormat = new OpenWireFormat();
     private SystemUsage usageManager;
     private LinkedBlockingQueue<Runnable> asyncQueueJobQueue;
@@ -118,19 +117,13 @@ public class KahaDBStore extends MessageDatabase implements PersistenceAdapter,
     // when true, message order may be compromised when cache is exhausted if store is out
     // or order w.r.t cache
     private boolean concurrentStoreAndDispatchTopics = false;
-    private final boolean concurrentStoreAndDispatchTransactions = false;
     private int maxAsyncJobs = MAX_ASYNC_JOBS;
     private final KahaDBTransactionStore transactionStore;
     private TransactionIdTransformer transactionIdTransformer;
 
     public KahaDBStore() {
         this.transactionStore = new KahaDBTransactionStore(this);
-        this.transactionIdTransformer = new TransactionIdTransformer() {
-            @Override
-            public TransactionId transform(TransactionId txid) {
-                return txid;
-            }
-        };
+        this.transactionIdTransformer = txid -> txid;
     }
 
     @Override
@@ -181,10 +174,6 @@ public class KahaDBStore extends MessageDatabase implements PersistenceAdapter,
         this.concurrentStoreAndDispatchTopics = concurrentStoreAndDispatch;
     }
 
-    public boolean isConcurrentStoreAndDispatchTransactions() {
-        return this.concurrentStoreAndDispatchTransactions;
-    }
-
     /**
      * @return the maxAsyncJobs
      */
@@ -218,8 +207,8 @@ public class KahaDBStore extends MessageDatabase implements PersistenceAdapter,
     public void doStart() throws Exception {
         //configure the metadata before start, right now
         //this is just the open wire version
+        LOG.info("Starting KahaDBStore");
         configureMetadata();
-
         super.doStart();
 
         if (brokerService != null) {
@@ -583,6 +572,29 @@ public class KahaDBStore extends MessageDatabase implements PersistenceAdapter,
                     }
                 }
             }, null);
+
+            /*
+             * After we store the command in the journal we no longer need to keep the message
+             * on the command, and we can clear the field here.
+             *
+             * The reason to clear the message is that for messages added as part of a transaction the command
+             * will be added to the inflightTransactions map as a pending add operation.
+             * For long-running transactions and/or transactions with a lot of pending messages
+             * (or large messages) this can use up a decent amount of memory which can increase GC pressure.
+             *
+             * The commands are only tracked in the map so that the KahaDB index can be updated later
+             * on transaction commit, but updating the index only requires metadata from the command
+             * such as message id or destination and not the message itself, so we can safely clear the field.
+             *
+             * Note that on broker restart and recovery of the KahaDB journal the pending message
+             * adds for transactions will be loaded again and the memory won't be cleared in that case.
+             * This could be revisited in the future if an issue but that should not be a large
+             * issue because that's only done on first startup and during recovery and then
+             * after the broker is recovered the memory footprint will drop. Also, as of now, recovering
+             * XA transactions in the transaction broker requires loading the messages and acks anyway
+             * for processing, so we need to load the full message and keep it in the pending operation.
+             */
+            command.clearMessage();
         }
 
         @Override
