@@ -138,6 +138,7 @@ public class StompTest extends StompTestSupport {
         connection.start();
         xstream = new XStream();
         xstream.processAnnotations(SamplePojo.class);
+        xstream.allowTypes(new Class[] { SamplePojo.class });
     }
 
     @Override
@@ -901,6 +902,7 @@ public class StompTest extends StompTestSupport {
         try {
             String f = stompConnection.receiveFrame();
             assertTrue(f.startsWith("ERROR"));
+            assertFalse("no stack trace impl leak:" + f, f.contains("at "));
         } catch (IOException socketMayBeClosedFirstByBroker) {}
     }
 
@@ -913,6 +915,7 @@ public class StompTest extends StompTestSupport {
         try {
             String f = stompConnection.receiveFrame();
             assertTrue(f.startsWith("ERROR"));
+            assertFalse("no stack trace impl leak:" + f, f.contains("at "));
         } catch (IOException socketMayBeClosedFirstByBroker) {}
     }
 
@@ -930,6 +933,7 @@ public class StompTest extends StompTestSupport {
         stompConnection.sendFrame(frame);
         String f = stompConnection.receiveFrame();
         assertTrue(f.startsWith("ERROR"));
+        assertFalse("no stack trace impl leak:" + f, f.contains("at "));
     }
 
     @Test(timeout = 60000)
@@ -946,6 +950,7 @@ public class StompTest extends StompTestSupport {
         stompConnection.sendFrame(frame);
         frame = stompConnection.receiveFrame();
         assertTrue(frame.startsWith("ERROR"));
+        assertFalse("no stack trace impl leak:" + frame, frame.contains("at "));
     }
 
     @Test(timeout = 60000)
@@ -964,6 +969,7 @@ public class StompTest extends StompTestSupport {
         frame = stompConnection.receiveFrame();
         assertTrue(frame.startsWith("ERROR"));
         assertTrue("Error Frame did not contain receipt-id", frame.indexOf(Stomp.Headers.Response.RECEIPT_ID) >= 0);
+        assertFalse("no stack trace impl leak:" + frame, frame.contains("at "));
     }
 
     @Test(timeout = 60000)
@@ -2279,6 +2285,45 @@ public class StompTest extends StompTestSupport {
         doTestAckInTransaction(false);
     }
 
+    @Test(timeout = 60000)
+    public void testFrameHeaderEscapes() throws Exception {
+        String connectFrame = "STOMP\n" +
+                "login:system\n" +
+                "passcode:manager\n" +
+                "accept-version:1.0\n" +
+                "host:localhost\n" +
+                "\n" + Stomp.NULL;
+        stompConnection.sendFrame(connectFrame);
+
+        String f = stompConnection.receiveFrame();
+        LOG.debug("Broker sent: " + f);
+
+        assertTrue(f.startsWith("CONNECTED"));
+
+        String frame = "SUBSCRIBE\n" + "destination:/queue/" + getQueueName() + "\n" +
+                "id:12345\n" +
+                "ack:auto\n\n" + Stomp.NULL;
+        stompConnection.sendFrame(frame);
+
+        String message = "SEND\n" + "destination:/queue/" + getQueueName() + "\n" +
+                "colon:\\c\n" +
+                "linefeed:\\n\n" +
+                "backslash:\\\\\n" +
+                "carriagereturn:\\r\n" +
+                "\n" + Stomp.NULL;
+        stompConnection.sendFrame(message);
+
+        frame = stompConnection.receiveFrame();
+
+        LOG.debug("Broker sent: " + frame);
+        assertTrue(frame.startsWith("MESSAGE"));
+        assertFalse(frame.contains("colon:\\c\n"));
+        assertFalse(frame.contains("linefeed:\\n\n"));
+        assertFalse(frame.contains("backslash:\\\\\n"));
+        assertFalse(frame.contains("carriagereturn:\\\\r\n"));
+
+    }
+
     public void doTestAckInTransaction(boolean topic) throws Exception {
 
         String frame = "CONNECT\n" + "login:system\n" + "passcode:manager\n\n" + Stomp.NULL;
