@@ -17,9 +17,11 @@
 package org.apache.activemq.broker.region.cursors;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 
 import java.io.IOException;
 import java.net.URI;
+import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
 
 import javax.jms.Connection;
@@ -46,8 +48,11 @@ import org.apache.activemq.util.SubscriptionKey;
 import org.apache.activemq.util.Wait;
 import org.apache.activemq.util.Wait.Condition;
 import org.junit.After;
+import org.junit.Assume;
 import org.junit.Before;
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.Timeout;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -67,6 +72,19 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
     protected String defaultQueueName = "test.queue";
     protected String defaultTopicName = "test.topic";
     protected static int maxMessageSize = 1000;
+    protected final boolean prioritizedMessages;
+    protected boolean enableSubscriptionStatistics;
+
+    @Rule
+    public Timeout globalTimeout= new Timeout(60, TimeUnit.SECONDS);
+
+    /**
+     * @param prioritizedMessages
+     */
+    public AbstractPendingMessageCursorTest(final boolean prioritizedMessages) {
+        super();
+        this.prioritizedMessages = prioritizedMessages;
+    }
 
     @Before
     public void startBroker() throws Exception {
@@ -86,6 +104,7 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
         PolicyEntry policy = new PolicyEntry();
         policy.setTopicPrefetch(100);
         policy.setDurableTopicPrefetch(100);
+        policy.setPrioritizedMessages(isPrioritizedMessages());
         PolicyMap pMap = new PolicyMap();
         pMap.setDefaultEntry(policy);
         broker.setDestinationPolicy(pMap);
@@ -114,8 +133,15 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
 
     protected abstract void initPersistence(BrokerService brokerService) throws IOException;
 
+    protected boolean isPrioritizedMessages() {
+        return prioritizedMessages;
+    }
+
     @Test
     public void testQueueMessageSize() throws Exception {
+        //doesn't apply to queues, only run once
+        Assume.assumeFalse(enableSubscriptionStatistics);
+
         AtomicLong publishedMessageSize = new AtomicLong();
 
         org.apache.activemq.broker.region.Queue dest = publishTestQueueMessages(200, publishedMessageSize);
@@ -125,6 +151,9 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
 
     @Test
     public void testQueueBrowserMessageSize() throws Exception {
+        //doesn't apply to queues, only run once
+        Assume.assumeFalse(enableSubscriptionStatistics);
+
         AtomicLong publishedMessageSize = new AtomicLong();
 
         org.apache.activemq.broker.region.Queue dest = publishTestQueueMessages(200, publishedMessageSize);
@@ -135,6 +164,9 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
 
     @Test
     public void testQueueMessageSizeNonPersistent() throws Exception {
+        //doesn't apply to queues, only run once
+        Assume.assumeFalse(enableSubscriptionStatistics);
+
         AtomicLong publishedMessageSize = new AtomicLong();
 
         org.apache.activemq.broker.region.Queue dest = publishTestQueueMessages(200,
@@ -144,6 +176,9 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
 
     @Test
     public void testQueueMessageSizePersistentAndNonPersistent() throws Exception {
+        //doesn't apply to queues, only run once
+        Assume.assumeFalse(enableSubscriptionStatistics);
+
         AtomicLong publishedNonPersistentMessageSize = new AtomicLong();
         AtomicLong publishedMessageSize = new AtomicLong();
 
@@ -157,6 +192,9 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
 
     @Test
     public void testQueueMessageSizeAfterConsumption() throws Exception {
+        //doesn't apply to queues, only run once
+        Assume.assumeFalse(enableSubscriptionStatistics);
+
         AtomicLong publishedMessageSize = new AtomicLong();
 
         org.apache.activemq.broker.region.Queue dest = publishTestQueueMessages(200, publishedMessageSize);
@@ -170,6 +208,9 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
 
     @Test
     public void testQueueMessageSizeAfterConsumptionNonPersistent() throws Exception {
+        //doesn't apply to queues, only run once
+        Assume.assumeFalse(enableSubscriptionStatistics);
+
         AtomicLong publishedMessageSize = new AtomicLong();
 
         org.apache.activemq.broker.region.Queue dest = publishTestQueueMessages(200, DeliveryMode.NON_PERSISTENT, publishedMessageSize);
@@ -181,7 +222,7 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
         verifyStoreStats(dest, 0, 0);
     }
 
-    @Test(timeout=60000)
+    @Test
     public void testTopicMessageSize() throws Exception {
         AtomicLong publishedMessageSize = new AtomicLong();
 
@@ -207,7 +248,7 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
         connection.close();
     }
 
-    @Test(timeout=60000)
+    @Test
     public void testTopicNonPersistentMessageSize() throws Exception {
         AtomicLong publishedMessageSize = new AtomicLong();
 
@@ -234,7 +275,7 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
         connection.close();
     }
 
-    @Test(timeout=60000)
+    @Test
     public void testTopicPersistentAndNonPersistentMessageSize() throws Exception {
         AtomicLong publishedMessageSize = new AtomicLong();
 
@@ -263,7 +304,7 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
         connection.close();
     }
 
-    @Test(timeout=60000)
+    @Test
     public void testMessageSizeOneDurable() throws Exception {
         AtomicLong publishedMessageSize = new AtomicLong();
         Connection connection = new ActiveMQConnectionFactory(brokerConnectURI).createConnection();
@@ -292,7 +333,7 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
         connection.close();
     }
 
-    @Test(timeout=60000)
+    @Test
     public void testMessageSizeOneDurablePartialConsumption() throws Exception {
         AtomicLong publishedMessageSize = new AtomicLong();
 
@@ -318,7 +359,7 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
         connection.close();
     }
 
-    @Test(timeout=60000)
+    @Test
     public void testMessageSizeTwoDurables() throws Exception {
         AtomicLong publishedMessageSize = new AtomicLong();
 
@@ -355,12 +396,12 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
     protected void verifyPendingStats(final org.apache.activemq.broker.region.Queue queue,
             final int count, final long minimumSize, final int storeCount, final long minimumStoreSize) throws Exception {
 
-        Wait.waitFor(new Condition() {
+        assertTrue(Wait.waitFor(new Condition() {
             @Override
             public boolean isSatisified() throws Exception {
                 return queue.getPendingMessageCount() == count;
             }
-        });
+        }));
 
         verifySize(count, new MessageSizeCalculator() {
             @Override
@@ -376,12 +417,12 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
 
         final TopicSubscription sub = (TopicSubscription) topic.getConsumers().get(0);
 
-        Wait.waitFor(new Condition() {
+        assertTrue(Wait.waitFor(new Condition() {
             @Override
             public boolean isSatisified() throws Exception {
                 return sub.getPendingQueueSize() == count;
             }
-        });
+        }));
 
         verifySize(count, new MessageSizeCalculator() {
             @Override
@@ -397,12 +438,12 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
         final DurableTopicSubscription sub = topic.getDurableTopicSubs().get(subKey);
 
         //verify message count
-        Wait.waitFor(new Condition() {
+        assertTrue(Wait.waitFor(new Condition() {
             @Override
             public boolean isSatisified() throws Exception {
                 return sub.getPendingQueueSize() == count;
             }
-        });
+        }));
 
         //verify message size
         verifySize(count, new MessageSizeCalculator() {
@@ -417,12 +458,12 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
             final int storeCount, final long minimumStoreSize) throws Exception {
         final MessageStore messageStore = dest.getMessageStore();
 
-        Wait.waitFor(new Condition() {
+        assertTrue(Wait.waitFor(new Condition() {
             @Override
             public boolean isSatisified() throws Exception {
                 return messageStore.getMessageCount() == storeCount;
             }
-        });
+        }));
         verifySize(storeCount, new MessageSizeCalculator() {
             @Override
             public long getMessageSize() throws Exception {
@@ -436,19 +477,19 @@ public abstract class AbstractPendingMessageCursorTest extends AbstractStoreStat
     protected void verifySize(final int count, final MessageSizeCalculator messageSizeCalculator,
             final long minimumSize) throws Exception {
         if (count > 0) {
-            Wait.waitFor(new Condition() {
+            assertTrue(Wait.waitFor(new Condition() {
                 @Override
                 public boolean isSatisified() throws Exception {
                     return messageSizeCalculator.getMessageSize() > minimumSize ;
                 }
-            });
+            }));
         } else {
-            Wait.waitFor(new Condition() {
+            assertTrue(Wait.waitFor(new Condition() {
                 @Override
                 public boolean isSatisified() throws Exception {
                     return messageSizeCalculator.getMessageSize() == 0;
                 }
-            });
+            }));
         }
     }
 
