@@ -51,7 +51,7 @@ import org.junit.Test;
 public class AMQ3537Test implements InvocationHandler, Serializable {
 
     static {
-        System.setProperty("org.apache.activemq.SERIALIZABLE_PACKAGES", "java.util,org.apache.activemq.bugs");
+        System.setProperty("org.apache.activemq.SERIALIZABLE_PACKAGES", "com.sun.proxy,java.util,org.apache.activemq.bugs");
     }
 
     private static final long serialVersionUID = 1L;
