@@ -21,12 +21,10 @@ import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 
+import java.lang.reflect.Array;
 import java.lang.reflect.Field;
 import java.net.URI;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.List;
-import java.util.Set;
+import java.util.*;
 import java.util.concurrent.ConcurrentMap;
 
 import javax.jms.JMSException;
@@ -65,8 +63,6 @@ import org.junit.runners.Parameterized.Parameters;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.Lists;
-
 /**
  * This test is to show that dynamicallyIncludedDestinations will work properly
  * when a network of brokers is configured to treat Virtual Destinations (Virtual topic and composite destination)
@@ -302,6 +298,30 @@ public class VirtualConsumerDemandTest extends DynamicNetworkTestSupport {
         assertAdvisoryBrokerCounts(1,1,1);
     }
 
+    // AMQ-8349 -Verify that replayed advisory messages for virtual consumers are only sent to
+    // new advisory consumers and not to existing by mistake
+    @Test(timeout = 30 * 1000)
+    public void testAdvisoryReplayMultipleAdvisoryConsumers() throws Exception {
+        Assume.assumeTrue(isUseVirtualDestSubsOnCreation);
+        ActiveMQQueue activemq = new ActiveMQQueue("include.test.bar.bridge");
+
+        //configure a virtual destination that forwards messages from topic testQueueName
+        //to queue "include.test.bar.bridge"
+        CompositeTopic compositeTopic = createCompositeTopic(testTopicName, activemq);
+        doSetUp(true, new VirtualDestination[] {compositeTopic}, true, true);
+        runtimeBroker.addNewDestination(activemq);
+
+        MessageConsumer advisoryConsumer1 = getVirtualDestinationAdvisoryConsumer(testTopicName);
+        //We should get 1 advisory replayed due to the virtual consumer demand for the composite queue
+        assertRemoteAdvisoryCount(advisoryConsumer1, 1);
+
+        MessageConsumer advisoryConsumer2 = getVirtualDestinationAdvisoryConsumer(testTopicName);
+        //We should get 1 advisory replayed on the new consumer but the existing consumer should not
+        //receive any messages as the advisory was already received before
+        assertRemoteAdvisoryCount(advisoryConsumer1, 0);
+        assertRemoteAdvisoryCount(advisoryConsumer2, 1);
+    }
+
     /**
      * Test that dynamic flow works for virtual destinations when a second composite
      * topic is included that forwards to the same queue, but is excluded from
@@ -1052,8 +1072,8 @@ public class VirtualConsumerDemandTest extends DynamicNetworkTestSupport {
 
         Thread.sleep(2000);
 
-        //there should be an extra advisory because of replay
-        assertRemoteAdvisoryCount(advisoryConsumer, 2);
+        //there should still only be 1 advisory
+        assertRemoteAdvisoryCount(advisoryConsumer, 1);
         assertAdvisoryBrokerCounts(1,1,1);
     }
 
@@ -1087,9 +1107,9 @@ public class VirtualConsumerDemandTest extends DynamicNetworkTestSupport {
         includedProducer.send(test);
         assertNotNull(bridgeConsumer.receive(5000));
 
-        //with isUseVirtualDestSubsOnCreation is true, there should be 4 advisories (2 replay)
-        //with !isUseVirtualDestSubsOnCreation, there should be 2 advisories (1 replay)
-        assertRemoteAdvisoryCount(advisoryConsumer, 4, 2);
+        //with isUseVirtualDestSubsOnCreation is true, there should be 2 advisories
+        //with !isUseVirtualDestSubsOnCreation, there should be 1 advisory
+        assertRemoteAdvisoryCount(advisoryConsumer, 2, 1);
         if (isUseVirtualDestSubsOnCreation) {
             assertAdvisoryBrokerCounts(1,2,1);
         } else {
@@ -1369,10 +1389,15 @@ public class VirtualConsumerDemandTest extends DynamicNetworkTestSupport {
         connector.setConduitSubscriptions(true);
         connector.setDuplex(isDuplex);
         connector.setUseVirtualDestSubs(true);
-        connector.setDynamicallyIncludedDestinations(Lists.newArrayList(new ActiveMQQueue(testQueueName),
-                new ActiveMQTopic(testTopicName + (forceDurable ? "?forceDurable=true" : "")), new ActiveMQTopic("VirtualTopic.>")));
-        connector.setExcludedDestinations(Lists.newArrayList(new ActiveMQQueue("exclude.test.foo"),
-                new ActiveMQTopic("exclude.test.bar")));
+        ArrayList<ActiveMQDestination> includedDestinations = new ArrayList<>();
+        includedDestinations.add(new ActiveMQQueue(testQueueName));
+        includedDestinations.add(new ActiveMQTopic(testTopicName + (forceDurable ? "?forceDurable=true" : "")));
+        includedDestinations.add(new ActiveMQTopic("VirtualTopic.>"));
+        connector.setDynamicallyIncludedDestinations(includedDestinations);
+        ArrayList<ActiveMQDestination> excludedDestinations = new ArrayList<>();
+        excludedDestinations.add(new ActiveMQQueue("exclude.test.foo"));
+        excludedDestinations.add(new ActiveMQTopic("exclude.test.bar"));
+        connector.setExcludedDestinations(excludedDestinations);
 
         if (startNetworkConnector) {
             brokerService.addNetworkConnector(connector);
@@ -1415,7 +1440,11 @@ public class VirtualConsumerDemandTest extends DynamicNetworkTestSupport {
         CompositeTopic compositeTopic = new CompositeTopic();
         compositeTopic.setName(name);
         compositeTopic.setForwardOnly(true);
-        compositeTopic.setForwardTo( Lists.newArrayList(forwardTo));
+        ArrayList<ActiveMQDestination> forwardToDestinations = new ArrayList<>();
+        for (ActiveMQDestination ft : forwardTo) {
+            forwardToDestinations.add(ft);
+        }
+        compositeTopic.setForwardTo(forwardToDestinations);
 
         return compositeTopic;
     }
@@ -1424,7 +1453,11 @@ public class VirtualConsumerDemandTest extends DynamicNetworkTestSupport {
         CompositeQueue compositeQueue = new CompositeQueue();
         compositeQueue.setName(name);
         compositeQueue.setForwardOnly(true);
-        compositeQueue.setForwardTo( Lists.newArrayList(forwardTo));
+        ArrayList<ActiveMQDestination> forwardToDestinations = new ArrayList<>();
+        for (ActiveMQDestination ft : forwardTo) {
+            forwardToDestinations.add(ft);
+        }
+        compositeQueue.setForwardTo(forwardToDestinations);
 
         return compositeQueue;
     }
