@@ -43,8 +43,8 @@ public class TopicSubscriptionInflightMessageSizeTest extends AbstractInflightMe
     }
 
     @Override
-    protected MessageConsumer getMessageConsumer() throws JMSException {
-        return session.createConsumer(dest);
+    protected MessageConsumer getMessageConsumer(String destName) throws JMSException {
+        return session.createConsumer(getDestination(destName));
     }
 
     @Override
@@ -53,12 +53,12 @@ public class TopicSubscriptionInflightMessageSizeTest extends AbstractInflightMe
     }
 
     @Override
-    protected Destination getDestination() throws JMSException {
+    protected Destination getDestination(String destName) throws JMSException {
         return session.createTopic(destName);
     }
 
     @Override
-    protected ActiveMQDestination getActiveMQDestination() {
+    protected ActiveMQDestination getActiveMQDestination(String destName) {
         return new ActiveMQTopic(destName);
     }
 
