@@ -45,7 +45,6 @@ import org.apache.activemq.broker.BrokerService;
 import org.apache.activemq.broker.region.policy.PolicyEntry;
 import org.apache.activemq.broker.region.policy.PolicyMap;
 import org.apache.activemq.command.ActiveMQTopic;
-import org.apache.activemq.leveldb.LevelDBStore;
 import org.apache.activemq.store.kahadb.KahaDBPersistenceAdapter;
 import org.apache.activemq.util.ThreadTracker;
 import org.junit.After;
@@ -849,7 +848,7 @@ public class DurableSubProcessConcurrentCommitActivateNoDuplicateTest {
     }
 
     private enum Persistence {
-        MEMORY, LEVELDB, KAHADB
+        MEMORY, KAHADB
     }
 
     private void startBroker() throws Exception {
@@ -870,17 +869,6 @@ public class DurableSubProcessConcurrentCommitActivateNoDuplicateTest {
             broker.setPersistent(false);
             break;
 
-        case LEVELDB:
-            File amqData = new File("activemq-data/" + getName() + "-leveldb");
-            if (deleteAllMessages)
-                delete(amqData);
-
-            broker.setPersistent(true);
-            LevelDBStore amq = new LevelDBStore();
-            amq.setDirectory(amqData);
-            broker.setPersistenceAdapter(amq);
-            break;
-
         case KAHADB:
             File kahadbData = new File("activemq-data/" + getName() + "-kahadb");
             if (deleteAllMessages)
